@@ -389,9 +389,11 @@ class BaseAuth(object):
         """
         backend_name = self.AUTH_BACKEND.name.upper().replace('-', '_')
         extra_arguments = setting(backend_name + '_AUTH_EXTRA_ARGUMENTS', {})
-        for key in extra_arguments:
+        for key, value in extra_arguments.iteritems():
             if key in self.data:
                 extra_arguments[key] = self.data[key]
+            elif value:
+                extra_arguments[key] = value
         return extra_arguments
 
     @property
@@ -513,7 +515,7 @@ class OpenIdAuth(BaseAuth):
                 max_age = None
 
         if (max_age is not None or preferred_policies is not None
-            or preferred_level_types is not None):
+           or preferred_level_types is not None):
             pape_request = pape.Request(
                 preferred_auth_policies=preferred_policies,
                 max_auth_age=max_age,
@@ -635,7 +637,7 @@ class ConsumerBasedOAuth(BaseOAuth):
         for unauthed_token in unauthed_tokens:
             token = Token.from_string(unauthed_token)
             if token.key == self.data.get('oauth_token', 'no-token'):
-                unauthed_tokens = list(set(unauthed_tokens) - \
+                unauthed_tokens = list(set(unauthed_tokens) -
                                        set([unauthed_token]))
                 self.request.session[name] = unauthed_tokens
                 self.request.session.modified = True
