@@ -20,6 +20,15 @@ USER_MODEL = setting('SOCIAL_AUTH_USER_MODEL') or \
              setting('AUTH_USER_MODEL') or \
              'auth.User'
 UID_LENGTH = setting('SOCIAL_AUTH_UID_LENGTH', 255)
+NONCE_SERVER_URL_LENGTH = setting('SOCIAL_AUTH_NONCE_SERVER_URL_LENGTH', 255)
+ASSOCIATION_SERVER_URL_LENGTH = setting(
+    'SOCIAL_AUTH_ASSOCIATION_SERVER_URL_LENGTH',
+    255
+)
+ASSOCIATION_HANDLE_LENGTH = setting(
+    'SOCIAL_AUTH_ASSOCIATION_HANDLE_LENGTH',
+    255
+)
 
 
 class UserSocialAuth(models.Model, UserSocialAuthMixin):
@@ -54,7 +63,7 @@ class UserSocialAuth(models.Model, UserSocialAuthMixin):
 
 class Nonce(models.Model, NonceMixin):
     """One use numbers"""
-    server_url = models.CharField(max_length=255)
+    server_url = models.CharField(max_length=NONCE_SERVER_URL_LENGTH)
     timestamp = models.IntegerField(db_index=True)
     salt = models.CharField(max_length=40)
 
@@ -65,8 +74,8 @@ class Nonce(models.Model, NonceMixin):
 
 class Association(models.Model, AssociationMixin):
     """OpenId account association"""
-    server_url = models.CharField(max_length=255)
-    handle = models.CharField(max_length=255)
+    server_url = models.CharField(max_length=ASSOCIATION_SERVER_URL_LENGTH)
+    handle = models.CharField(max_length=ASSOCIATION_HANDLE_LENGTH)
     secret = models.CharField(max_length=255)  # Stored base64 encoded
     issued = models.IntegerField(db_index=True)
     lifetime = models.IntegerField()
